==> replacer-1.0.2%2B1.21.%282-4%29-Fabric-sources.jar: eva/replacer/util/BuildInProgress.java <==
package eva.replacer.util;

import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_3468;
import net.minecraft.class_3965;

import static eva.replacer.util.RelPos.origin;

public class BuildInProgress {
    private static final List<RelPos> posList = new ArrayList<>();
    private static class_1750 context;
    private static final List<RelPos> placedList = new ArrayList<>();
    private static boolean rePlacing = false;

    public static boolean rePlacing() {
        return rePlacing;
    }

    public static void rePlacing(boolean re) {
        rePlacing = re;
    }

    public static void pass(RelPos pos) {
        assert context.method_8036() != null;
        if (context.method_8036().method_56093(pos.pos(), context.method_8036().method_55754() + 1))
            posList.add(pos);
    }
    public static void pass(class_1750 cont) {
        context = cont;
    }

    public static void clear() {
        posList.clear();
        context = null;
        placedList.clear();
    }

    public static boolean isClear() {
        return posList.size() + placedList.size() == 0;
    }

    public static class_1750 context() {return context;}

    public static RelPos next() {
        placedList.add(posList.removeFirst());
        return placedList.getLast();
    }

    public static boolean isEmpty() {
        return posList.isEmpty();
    }

    public static class_3965 place(RelPos pos, @Nullable class_1750 context, class_1657 player, class_1747 blit) {
        if (context == null) context = context();
        if (!player.method_5998(context.method_20287()).method_7960())
            if (!pos.equals(origin))
                if (context.method_8045().method_8320(pos.pos()).method_45474()) {
                    class_3965 res = new class_3965(
                            pos.vec(),
                            context.method_8038(),
                            pos.pos(),
                            context.method_17699()
                    );
                    blit.method_7712(
                            new class_1750(
                                    player,
                                    context.method_20287(),
                                    player.method_5998(context.method_20287()),
                                    res
                            )
                    );
                    player.method_7259(class_3468.field_15372.method_14956(blit));
                    return res;
                }
        return class_3965.method_17778(pos.vec(), context.method_8038(), pos.pos());
    }
}

==> replacer-1.1.1%2B1.21.%282-4%29-Fabric-sources.jar: eva/replacer/util/BuildInProgress.java <==
package eva.replacer.util;

import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_3468;
import net.minecraft.class_3965;

import static eva.replacer.util.RelPos.origin;

public class BuildInProgress {
    private static final List<RelPos> posList = new ArrayList<>();
    private static class_1750 context;
    private static final List<RelPos> placedList = new ArrayList<>();
    private static boolean rePlacing = false;
    private static boolean readyForBlock = false;

    public static boolean rePlacing() {
        return rePlacing;
    }

    public static void rePlacing(boolean re) {
        rePlacing = re;
    }

    public static void pass(RelPos pos) {
        assert context.method_8036() != null;
        if (context.method_8036().method_56093(pos.pos(), context.method_8036().method_55754() + 1))
            posList.add(pos);
    }
    public static void pass(class_1750 cont) {
        context = cont;
    }

    public static void clear() {
        posList.clear();
        context = null;
        placedList.clear();
    }

    public static boolean isClear() {
        return posList.size() + placedList.size() == 0;
    }

    public static class_1750 context() {return context;}

    public static RelPos next() {
        placedList.add(posList.removeFirst());
        return placedList.getLast();
    }

    public static RelPos last() {
        if (placedList.isEmpty()) return origin;
        return placedList.getLast();
    }

    public static boolean isEmpty() {
        return posList.isEmpty();
    }

    public static class_3965 place(RelPos pos, @Nullable class_1750 context, class_1657 player, class_1747 blit) {
        if (context == null) context = context();
        if (!player.method_5998(context.method_20287()).method_7960())
            if (!pos.equals(origin))
                if (context.method_8045().method_8320(pos.pos()).method_26166(context)) {
                    class_3965 res = new class_3965(
                            pos.vec(),
                            context.method_8038(),
                            pos.pos(),
                            context.method_17699()
                    );
                    blit.method_7712(
                            new class_1750(
                                    player,
                                    context.method_20287(),
                                    player.method_5998(context.method_20287()),
                                    res
                            )
                    );
                    player.method_7259(class_3468.field_15372.method_14956(blit));
                    return res;
                }
        return class_3965.method_17778(pos.vec(), context.method_8038(), pos.pos());
    }

    public static boolean isReadyForBlock() {
        return readyForBlock;
    }

    public static void setReadyForBlock(boolean readyForBlock) {
        BuildInProgress.readyForBlock = readyForBlock;
    }
}
